// http://cxem.net/arduino/arduino86.php

#include <Adafruit_GFX.h>
#include <Adafruit_PCD8544.h>

#define VoltPin A0  // Voltage pin
#define CurrPin A1  // Current pin

float kVD = 5;  // Коэффициент делителя напряжения (Divider Ratio)
float kI = 1;   // Коэффициент для пересчета тока нагрузки - значение резистора Rg (Current Ratio - value of Rg resistor)

// pin 7 - Serial clock out (SCLK)
// pin 6 - Serial data out (DIN)
// pin 5 - Data/Command select (D/C)
// pin 4 - LCD chip select (CS)
// pin 3 - LCD reset (RST)
Adafruit_PCD8544 display = Adafruit_PCD8544(7, 6, 5, 4, 3);

int VoltageValue; 
int CurrentValue;
float voltage;
float current;

void setup()   {
  display.begin();
  display.setContrast(40);    // установка контрастности дисплея
  delay(1000);
  display.clearDisplay();     // очистка экрана и буфера (clears the screen and buffer)
  display.setTextSize(1);     // установка размера текста (set text size)
  display.setTextColor(BLACK);
  delay(1000);
}

void loop() {
  VoltageValue = analogRead(VoltPin);               // считываем значение аналогового входа (напряжение)
  CurrentValue = analogRead(CurrPin);               // считываем значение аналогового входа (ток)
  voltage = VoltageValue * (5.0 / 1023.0) * kVD;    // расчет напряжения (voltage calculation)
  current = (CurrentValue * (5.0 / 1023.0)) / kI;   // расчет тока (current calculation)
  
  display.clearDisplay();              // очистка экрана и буфера (clears the screen and buffer)
  display.setCursor(0,0);              // установка курсора в позицию 0,0
  
  display.print("Voltage=");           // вывод надписи
  display.println(voltage);            // вывод значения напряжения с переводом строки
  display.println();                   // перевод строки
  
  display.print("Current=");
  display.println(current);
  display.println();  
  
  display.print("Power=");
  display.println(current * voltage);  // расчет мощности (power calculation)
  
  display.display();                   // вывод данных на дисплей
  
  delay(500);                          // задержка 500 мс
}
